<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi" sourcelanguage="en_US">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="363"/>
        <source>Learn Basic Operations</source>
        <translation>Opettele perustoiminnot</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="366"/>
        <source>Common Application Libraries</source>
        <translation>Yleiset sovelluskirjastot</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="369"/>
        <source>Desktop Environment</source>
        <translation>Työpöytäympäristö</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="291"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>Etsi &quot;%1&quot; koko tekstistä</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="363"/>
        <source>The content was updated</source>
        <translation>Sisältö päivitettiin</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="767"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
        <location filename="../src/view/web_window.cpp" line="771"/>
        <source>Support</source>
        <translation>Tuki</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="1038"/>
        <source>Copy</source>
        <translation>Kopio</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>Quick Start</source>
        <translation>Nopea aloitus</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Video Guide</source>
        <translation>Video opas</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>System</source>
        <translation>Järjestelmä</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>Applications</source>
        <translation>Sovellukset</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>Home</source>
        <translation>Koti</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>  result</source>
        <translation>tulos</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>  results</source>
        <translation>tulokset</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
        <source>Click to view </source>
        <translation>Paina ja katso</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
        <source>View all</source>
        <translation>Näytä kaikki</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
        <source>App Store</source>
        <translation>App Store</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="136"/>
        <source>Manual</source>
        <translation>Käyttöohje</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="137"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>Käyttöjärjestelmän käsikirja on suunniteltu auttamaan käyttäjiä tarjoamalla erityisiä ohjeita ja toimintokuvauksia ohjelmista.</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="952"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="969"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>
